@@ -141,12 +141,19 @@ def lemmatization(status_logger_name, textual_data, allowed_postags=['NOUN', 'AD
 
 	return texts_out
 
-def nlp_engine_main(abstracts_log_name, status_logger_name):
+def nlp_engine_main(abstracts_log_name, status_logger_name, num_topics = None, num_keywords = None):
 	nlp_engine_main_start_status_key = "Initiating the NLP Engine"
 	status_logger(status_logger_name, nlp_engine_main_start_status_key)
 
 	'''Declaring the number of topics to be generated by the LDA model'''
-	num_topics = 10
+	if num_topics == None:
+		'''If the user has not provided this argument then set to 10'''
+		num_topics = 10
+
+	'''Declaring the number of keywords to be presented by the Visualizer'''
+	if num_keywords == None:
+		'''If the user has not provided this argument then set to 20'''
+		num_keywords = 20
 
 	'''Extracts the data from the .txt file and puts them into a Pandas dataframe buckets'''
 	textual_dataframe = data_reader(abstracts_log_name, status_logger_name)
@@ -156,7 +163,7 @@ def nlp_engine_main(abstracts_log_name, status_logger_name):
 	textual_data_no_stops = remove_stopwords(textual_data, status_logger_name)
 	'''Prepares bigrams'''
 	textual_data_words_bigrams = make_bigrams(textual_data_no_stops, status_logger_name)
-	'''Running -> Run'''
+	'''Lemmatization: Running -> Run'''
 	textual_data_lemmatized = lemmatization(status_logger_name, textual_data_words_bigrams, allowed_postags=['NOUN', 'ADJ', 'VERB', 'ADV'])
 	'''Creating a dictionary for each term as the key, and the value as their frequency in that sentence.'''
 	id2word = corpora.Dictionary(textual_data_lemmatized)
@@ -183,6 +190,6 @@ def nlp_engine_main(abstracts_log_name, status_logger_name):
 	status_logger(status_logger_name, nlp_engine_main_end_status_key)
 
 	'''Importing the visualizer_main function to view the LDA Model built by the NLP_engine_main() function'''
-	visualizer_main(lda_model, corpus, id2word, textual_data_lemmatized, num_topics, abstracts_log_name, status_logger_name)
+	visualizer_main(lda_model, corpus, id2word, textual_data_lemmatized, num_topics, num_keywords, abstracts_log_name, status_logger_name)
 
 	return 0
\ No newline at end of file
